@@ -101,12 +101,11 @@ const SASLAuthHandler = new Lang.Class({
         let account = this._channel.connection.get_account();
         let prompt = new GLib.Variant('b', false);
         let params = new GLib.Variant('a{sv}', { 'password-prompt': prompt });
-        account.update_parameters_vardict_async(params, [], Lang.bind(this,
-            function(a, res) {
-                a.update_parameters_vardict_finish(res);
-                account.request_presence_async(Tp.ConnectionPresenceType.AVAILABLE,
-                                               'available', '', null);
-            }));
+        account.update_parameters_vardict_async(params, [], (a, res) => {
+            a.update_parameters_vardict_finish(res);
+            account.request_presence_async(Tp.ConnectionPresenceType.AVAILABLE,
+                                           'available', '', null);
+        });
     }
 });
 
@@ -194,24 +193,25 @@ const TelepathyClient = new Lang.Class({
         this._accountsMonitor.connect('account-enabled', (mon, account) => {
             this._connectAccount(account);
         });
-        this._accountsMonitor.enabledAccounts.forEach(a => {
-            this._onAccountStatusChanged(this._accountsMonitor, a);
-        });
 
-        this._networkMonitor.connect('network-changed',
-                                     Lang.bind(this, this._onNetworkChanged));
-        this._onNetworkChanged(this._networkMonitor,
-                               this._networkMonitor.network_available);
+        this._networkMonitor.connect('notify::network-available',
+                                     Lang.bind(this, this._onNetworkAvailableChanged));
+        this._onNetworkAvailableChanged();
     },
 
-    _onNetworkChanged: function(mon, connected) {
+    _onNetworkAvailableChanged: function() {
+        let connected = this._networkMonitor.network_available;
         let presence = connected ? Tp.ConnectionPresenceType.AVAILABLE
                                  : Tp.ConnectionPresenceType.OFFLINE;
         debug('Network changed to %s'.format(connected ? 'available'
                                                        : 'unavailable'));
 
         this._accountsMonitor.enabledAccounts.forEach(a => {
-            this._setAccountPresence(a, presence);
+            if (a.requested_presence_type == Tp.ConnectionPresenceType.AVAILABLE &&
+                a.connection_status == Tp.ConnectionStatus.CONNECTED)
+                this._onAccountStatusChanged(this._accountsMonitor, a);
+            else
+                this._setAccountPresence(a, presence);
         });
     },
 
@@ -301,7 +301,6 @@ const TelepathyClient = new Lang.Class({
         let params = account.dup_parameters_vardict().deep_unpack();
         let username = settings.get_string('identify-username') ||
                        params.username.deep_unpack();
-        let alwaysSendUsername = settings.get_boolean('identify-username-supported');
         let contactName = settings.get_string('identify-botname');
         let command = settings.get_string('identify-command');
         this._requestChannel(account, Tp.HandleType.CONTACT, contactName,
@@ -310,11 +309,6 @@ const TelepathyClient = new Lang.Class({
                     return;
 
                 let room = this._roomManager.lookupRoomByChannel(channel);
-                let activeNick = room.channel.connection.self_contact.alias;
-                // Omit username parameter when it matches the default, to
-                // support NickServ bots that don't support the parameter at all
-                if (!alwaysSendUsername && activeNick == username)
-                    username = null;
                 room.send_identify_message_async(command, username, password, (r, res) => {
                     try {
                         r.send_identify_message_finish(res);
@@ -359,14 +353,12 @@ const TelepathyClient = new Lang.Class({
 
         let prompt = new GLib.Variant('b', password.length > 0);
         let params = GLib.Variant.new('a{sv}', { 'password-prompt': prompt });
-        account.update_parameters_vardict_async(params, [],
-            Lang.bind(this, function(a, res) {
-                a.update_parameters_vardict_finish(res);
-                Utils.storeAccountPassword(a, password, Lang.bind(this,
-                    function() {
-                        a.reconnect_async(null);
-                    }));
-            }));
+        account.update_parameters_vardict_async(params, [], (a, res) => {
+            a.update_parameters_vardict_finish(res);
+            Utils.storeAccountPassword(a, password, () => {
+                a.reconnect_async(null);
+            });
+        });
     },
 
     _onQueryActivated: function(action, parameter) {
@@ -444,7 +436,6 @@ const TelepathyClient = new Lang.Class({
             settings.set_string('identify-command', data.command);
 
         settings.set_string('identify-username', data.username);
-        settings.set_boolean('identify-username-supported', data.usernameSupported);
     },
 
     _onDiscardIdentifyPasswordActivated: function(action, parameter) {
@@ -487,45 +478,43 @@ const TelepathyClient = new Lang.Class({
 
     vfunc_observe_channels: function(account, connection, channels,
                                      op, requests, context) {
-        this._processRequest(context, connection, channels, Lang.bind(this,
-            function(channel) {
-                if (this._isAuthChannel(channel))
-                    return;
+        this._processRequest(context, connection, channels, channel => {
+            if (this._isAuthChannel(channel))
+                return;
 
-                if (channel.has_interface(Tp.IFACE_CHANNEL_INTERFACE_GROUP)) {
-                    let [invited, , , ,] = channel.group_get_local_pending_contact_info(channel.group_self_contact);
-                    if (invited)
-                      // this is an invitation - only add it in handleChannel
-                      // if accepted
-                      return;
-                }
+            if (channel.has_interface(Tp.IFACE_CHANNEL_INTERFACE_GROUP)) {
+                let [invited, , , ,] = channel.group_get_local_pending_contact_info(channel.group_self_contact);
+                if (invited)
+                  // this is an invitation - only add it in handleChannel
+                  // if accepted
+                  return;
+            }
 
-                channel.connect('message-received',
-                                Lang.bind(this, this._onMessageReceived));
-                channel.connect('pending-message-removed',
-                                Lang.bind(this, this._onPendingMessageRemoved));
+            channel.connect('message-received',
+                            Lang.bind(this, this._onMessageReceived));
+            channel.connect('pending-message-removed',
+                            Lang.bind(this, this._onPendingMessageRemoved));
 
-                this._roomManager.ensureRoomForChannel(channel, 0);
-            }));
+            this._roomManager.ensureRoomForChannel(channel, 0);
+        });
     },
 
     vfunc_handle_channels: function(account, connection, channels,
                                     satisfied, userTime, context) {
         let [present, ] = Tp.user_action_time_should_present(userTime);
 
-        this._processRequest(context, connection, channels, Lang.bind(this,
-            function(channel) {
-                if (this._isAuthChannel(channel)) {
-                    let authHandler = new SASLAuthHandler(channel);
-                    return;
-                }
+        this._processRequest(context, connection, channels, channel => {
+            if (this._isAuthChannel(channel)) {
+                let authHandler = new SASLAuthHandler(channel);
+                return;
+            }
 
-                if (present)
-                    this._app.activate();
+            if (present)
+                this._app.activate();
 
-                this._roomManager.ensureRoomForChannel(channel, userTime);
-                //channel.join_async('', null);
-            }));
+            this._roomManager.ensureRoomForChannel(channel, userTime);
+            //channel.join_async('', null);
+        });
     },
 
     _getPendingNotificationID: function(room, id) {
@@ -567,7 +556,6 @@ const TelepathyClient = new Lang.Class({
             botname: room.channel.target_contact.alias,
             command: command,
             username: username || room.channel.connection.self_contact.alias,
-            usernameSupported: username != null,
             password: password
         };
         this._pendingBotPasswords.set(accountPath, data);
